'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');
var chalk = require('chalk');


var BedrockGenerator = yeoman.generators.Base.extend({
  init: function () {
    this.pkg = yeoman.file.readJSON(path.join(__dirname, '../package.json'));

    this.on('end', function () {
      this.installDependencies({ skipInstall: this.options['skip-install'] });
    });
  },

  askFor: function () {
    var done = this.async();

    // have Yeoman greet the user
    console.log(this.yeoman);

    // replace it with a short and sweet description of your generator
    console.log(chalk.magenta('You\'re using the fantastic Bedrock generator.'));

    var prompts = [
    {
      type: 'confirm',
      name: 'sassFolders',
      message: 'Would you like me tu structure your SASS files?',
      default: true
    },
    {
      type: 'confirm',
      name: 'fontAwesome',
      message: 'Would you like to include FontAwesome?',
      default: true
    }];

    this.prompt(prompts, function (props) {
      this.sassFolders = props.sassFolders;
      this.fontAwesome = props.fontAwesome;

      done();
    }.bind(this));
  },

  packageJSON: function () {
    this.template('_package.json', 'package.json');
  },

  gruntfile: function () {
    this.template('Gruntfile.js', 'Gruntfile.js');
  },

  editorConfig: function () {
    this.copy('editorconfig', '.editorconfig');
  },

  bower: function () {
    this.copy('_bower.json', 'bower.json');
    this.copy('bowerrc', '.bowerrc');
  },

  jshint: function () {
    this.copy('jshintrc', '.jshintrc');
  },

  git: function () {
    this.copy('gitignore', '.gitignore');
    this.copy('gitattributes', '.gitattributes');
  },

  projectFiles: function () {
    this.template('index.html', 'app/index.html');
    this.copy('main.js', 'app/scripts/main.js');
  },

  scssFiles: function () {
    if (this.sassFolders) {
      this.mkdir('app/styles/modules');
      this.mkdir('app/styles/partials');

      this.copy('styles/_foundation-settings.scss', 'app/styles/modules/_foundation-settings.scss');
      this.copy('styles/_google-fonts.scss', 'app/styles/modules/_google-fonts.scss');
      this.copy('styles/_modules.scss', 'app/styles/modules/_all.scss');
      this.copy('styles/_partials.scss', 'app/styles/partials/_base.scss');
      this.copy('styles/main.scss', 'app/styles/main.scss');
    } else {
      this.copy('styles/_foundation-settings.scss', 'app/styles/_settings.scss')
      this.copy('styles/app.scss', 'app/styles/app.scss');
    }
  },

  app: function () {
    this.mkdir('app');
    this.mkdir('app/images');
    this.mkdir('app/styles');
    this.mkdir('app/styles/fonts');
    this.mkdir('app/scripts');
  }

});

module.exports = BedrockGenerator;
