// Generated on <%= (new Date).toISOString().split('T')[0] %> using <%= pkg.name %> <%= pkg.version %>
'use strict';

module.exports = function (grunt) {
    require('time-grunt')(grunt);

    require('load-grunt-tasks')(grunt);

    var yeomanConfig = {
        app: 'app',
        dist: 'dist',
        tmp: '.tmp'
    };

    grunt.initConfig({
        yeoman: yeomanConfig,
        watch: {
            compass: {
                files: ['<%%= yeoman.app %>/styles/{,*/}{,*/}*.{scss,sass}'],
                tasks: ['compass:server']
            },
            livereload: {
                options: {
                    livereload: true,
                },
                files: [
                    '<%%= yeoman.app %>/*.html',
                    '{<%%= yeoman.tmp %>,<%%= yeoman.app %>}/styles/{,*/}*.css',
                    '{<%%= yeoman.tmp %>,<%%= yeoman.app %>}/scripts/{,*/}*.js',
                    '<%%= yeoman.app %>/images/{,*/}*.{png,jpg,jpeg,gif,webp,svg}'
                ]
            }
        },
        connect: {
            options: {
                port: 9000,
                hostname: 'localhost',
                livereload: true
            },
            livereload: {
                options: {
                    base: ['<%%= yeoman.tmp %>', '<%%= yeoman.app %>']
                }
            },
            dist: {
                options: {
                  base: '<%%= yeoman.dist %>',
                  keepalive: true,
                  livereload: false
                }
            }
        },
        open: {
            server: {
                path: 'http://localhost:<%%= connect.options.port %>'
            }
        },
        clean: {
            dist: {
                files: [{
                    dot: true,
                    src: [
                        '<%%= yeoman.tmp %>',
                        '<%%= yeoman.dist %>/*',
                        '!<%%= yeoman.dist %>/.git*'
                    ]
                }]
            },
            server: '<%%= yeoman.tmp %>'
        },
        jshint: {
            options: {
                jshintrc: '.jshintrc',
                reporter: require('jshint-stylish')
            },
            all: [
                '<%%= yeoman.app %>/scripts/{,*/}*.js',
                '!<%%= yeoman.app %>/scripts/vendor/*',
                'test/spec/{,*/}*.js'
            ]
        },
        compass: {
            options: {
                sassDir: '<%%= yeoman.app %>/styles',
                cssDir: '<%%= yeoman.tmp %>/styles',
                generatedImagesDir: '<%%= yeoman.tmp %>/images/generated',
                imagesDir: '<%%= yeoman.app %>/images',
                javascriptsDir: '<%%= yeoman.app %>/scripts',
                fontsDir: '<%%= yeoman.app %>/styles/fonts',
                importPath: [
                  '<%%= yeoman.app %>/bower_components/',
                  '<%%= yeoman.app %>/bower_components/foundation/scss'<% if (fontAwesome) { %>,
                  '<%%= yeoman.app %>/bower_components/font-awesome/scss'
                  <% } %>
                ],
                httpStylesheetsPath: '.',
                httpImagesPath: '../images',
                httpGeneratedImagesPath: '../images/generated',
                httpFontsPath: 'fonts',
                relativeAssets: false
            },
            dist: {},
            server: {
                options: {
                    debugInfo: true
                }
            }
        },
        filerev: {
            dist: {
              src: [
                  '<%%= yeoman.dist %>/scripts/{,*/}*.js',
                  '<%%= yeoman.dist %>/styles/{,*/}*.css',
                  '<%%= yeoman.dist %>/images/{,*/}*.{png,jpg,jpeg,gif,webp}',
                  '<%%= yeoman.dist %>/styles/fonts/*'
              ]
            }
        },
        modernizr: {
            "devFile" : "<%%= yeoman.app %>/bower_components/modernizr/modernizr.js",
            "outputFile" : "<%%= yeoman.dist %>/scripts/modernizr.js",
            "extra" : {
                "shiv" : true,
                "printshiv" : false,
                "load" : true,
                "mq" : false,
                "cssclasses" : true
            },
            "extensibility" : {
                "addtest" : false,
                "prefixed" : false,
                "teststyles" : false,
                "testprops" : false,
                "testallprops" : false,
                "hasevents" : false,
                "prefixes" : false,
                "domprefixes" : false
            },
            "uglify" : true,
            "tests" : [],
            "parseFiles" : true,
            // When parseFiles = true, this task will crawl all *.js, *.css, *.scss files, except files that are in node_modules/.
            // You can override this by defining a "files" array below.
            // "files" : [],
            "matchCommunityTests" : false,
            "customTests" : []
        },
        useminPrepare: {
            options: {
                dest: '<%%= yeoman.dist %>'
            },
            html: '<%%= yeoman.app %>/index.html'
        },
        usemin: {
            options: {
                assetsDirs: [
                  '<%%= yeoman.dist %>',
                  '<%%= yeoman.dist %>/styles'
                  ]
            },
            html: ['<%%= yeoman.dist %>/{,*/}*.html'],
            css: ['<%%= yeoman.dist %>/styles/{,*/}*.css']
        },
        imagemin: {
            dist: {
                options: {
                    cache: false
                },
                files: [{
                    expand: true,
                    cwd: '<%%= yeoman.app %>/images',
                    src: '{,*/}*.{png,jpg,jpeg}',
                    dest: '<%%= yeoman.dist %>/images'
                }]
            }
        },
        htmlmin: {
            dist: {
                options: {
                    /*removeCommentsFromCDATA: true,
                    // https://github.com/yeoman/grunt-usemin/issues/44
                    //collapseWhitespace: true,
                    collapseBooleanAttributes: true,
                    removeAttributeQuotes: true,
                    removeRedundantAttributes: true,
                    useShortDoctype: true,
                    removeEmptyAttributes: true,
                    removeOptionalTags: true*/
                },
                files: [{
                    expand: true,
                    cwd: '<%%= yeoman.app %>',
                    src: '*.html',
                    dest: '<%%= yeoman.dist %>'
                }]
            }
        },
        cssmin: {
          options: {
            keepSpecialComments: 0,
            report: 'min'
          }
        },
        uglify: {
          options: {
            report: 'min',
            preserveComments: 'some'
          }
        },
        copy: {<% if (fontAwesome) { %>
            fontawesome: {
                files: [{
                    expand: true,
                    flatten: true,
                    src: ['<%%= yeoman.app %>/bower_components/font-awesome/fonts/**'],
                    dest: '<%%= yeoman.tmp %>/styles/fonts/',
                    filter: 'isFile'
                }]
            },<% } %>
            dist: {
                files: [{
                    expand: true,
                    dot: true,
                    cwd: '<%%= yeoman.app %>',
                    dest: '<%%= yeoman.dist %>',
                    src: [
                        '*.{ico,txt}',
                        '.htaccess',
                        'images/{,*/}*.webp',
                        'styles/fonts/*'
                    ]
                }, {
                    expand: true,
                    cwd: '.tmp/images',
                    dest: '<%%= yeoman.dist %>/images',
                    src: [
                        'generated/*'
                    ]
                }<% if (fontAwesome) { %>, {
                    expand: true,
                    flatten: true,
                    src: ['<%%= yeoman.app %>/bower_components/font-awesome/fonts/**'],
                    dest: '<%%= yeoman.dist %>/styles/fonts/',
                    filter: 'isFile'
                } <% } %>]
            }
        },
        concurrent: {
            dist: [
                'compass:dist',
                'imagemin',
                'htmlmin'
            ]
        }
    });

    grunt.registerTask('default', [
        'jshint',
        'test',
        'build'
    ]);

    grunt.registerTask('build', [
        'clean:dist',
        'useminPrepare',
        'concurrent:dist',
        'concat',
        'cssmin',
        'uglify',
        'copy:dist',
        'filerev',
        'usemin'
    ]);

    grunt.registerTask('server', function (target) {
        if (target === 'dist') {
            return grunt.task.run(['build', 'open', 'connect:dist']);
        }

        grunt.task.run([
            'clean:server',
            'compass:server',
            'copy:fontawesome',
            'connect:livereload',
            'open:server',
            'watch'
        ]);
    });

    // grunt.registerTask('test', [
    //     'clean:server',
    //     'compass',
    //     'connect:test'
    // ]);
}
